from typing import Optional

from pydantic import BaseModel, Field


class Knowledge(BaseModel):
    id: str = Field(description="ID")
    nickname: Optional[str] = Field(description="knowledge nickname", default="")
    description: Optional[str] = Field(description="knowledge description", default="")



from typing import Optional

from pydantic import BaseModel, Field


class Prompt(BaseModel):
    introduction: Optional[str] = Field(description="prompt introduction", default="")
    target: Optional[str] = Field(description="prompt target", default="")
    instruction: Optional[str] = Field(description="prompt instruction", default="")



import shutil
from fastapi import APIRouter, Form,File, UploadFile
from magent_ui.config import app_config

router = APIRouter()
resource_router = router

@router.post("/resource/uploadfile")
async def upload_resource_file(file: UploadFile = File(...), filename:str= Form(...)):
    file_location = app_config.resource_dir_path.joinpath(filename)
    with open(file_location, "wb") as buffer:
        shutil.copyfileobj(file.file, buffer)
    return {"filename": filename}



from typing import List
from fastapi import APIRouter, HTTPException
from agentuniverse_product.service.tool_service.tool_service import ToolService
from agentuniverse_product.service.model.tool_dto import ToolDTO

router = APIRouter()
tools_router = router


@router.get("/tools", response_model=List[ToolDTO])
async def get_agents():
    return ToolService.get_tool_list()



from fastapi import APIRouter
from agentuniverse_product.base.util.common_util import is_component_id_unique

router = APIRouter()
common_router = router


@router.get("/common/is_id_unique", response_model=bool)
async def is_id_unique(id:str, type:str):
    result = is_component_id_unique(id,type)
    return result




from typing import Optional

from pydantic import BaseModel, Field


class Message(BaseModel):
    id: str = Field(description="ID")
    session_id: str = Field(description="Session ID")
    content: Optional[str] = Field(description="message content", default="")
    gmt_created: Optional[str] = Field(description="message create time")
    gmt_modified: Optional[str] = Field(description="message update time")



from typing import Optional
from pydantic import BaseModel, Field
from magent_ui.models.llm import Llm
from magent_ui.models.prompt import Prompt
from magent_ui.models.planner import Planner
from magent_ui.models.knowledge import Knowledge
from magent_ui.models.tool import Tool

class Agent(BaseModel):
    id: str = Field(description="ID")
    nickname: Optional[str] = Field(description="agent nickname", default="")
    avatar: Optional[str] = Field(description="agent avatar path", default="")
    description: Optional[str] = Field(description="agent description", default="")
    opening_speech: Optional[str] = Field(description="agent opening speech", default="")
    prompt: Optional[Prompt] = Field(description="agent prompt", default=None)
    llm: Optional[Llm] = Field(description="agent llm", default=None)
    tool: Optional[list[Tool]] = Field(description="agent tool list", default=[])
    memory: Optional[str] = Field(description="agent memory id", default='')
    planner: Optional[Planner] = Field(description="agent planner", default=None)
    knowledge: Optional[list[Knowledge]] = Field(description="agent knowledge list", default=[])
